@@ -2,6 +2,7 @@
 ## Example: Exponential Scale Family
 ###############################################################################
 require(ROptEst)
+options("newDevice"=TRUE)
 
 ## generates Exponential Scale Family with scale = 0.5 (rate = 2)
 E1 <- ExpScaleFamily(scale = 0.5) 
@@ -19,7 +20,7 @@ plot(E1.IC0) # plot IC
 ## L_2 family + infinitesimal neighborhood
 E1.Rob1 <- InfRobModel(center = E1, neighbor = ContNeighborhood(radius = 0.5))
 E1.Rob1     # show E1.Rob1
-E1.Rob2 <- InfRobModel(center = E1, neighbor = TotalVarNeighborhood(radius = 0.5))
+(E1.Rob2 <- InfRobModel(center = E1, neighbor = TotalVarNeighborhood(radius = 0.5)))
 
 ## MSE solution
 (E1.IC1 <- optIC(model=E1.Rob1, risk=asMSE()))
@@ -109,6 +110,14 @@ estimate(E1.est21)
 estimate(E1.est22)
 estimate(E1.est23)
 
+## confidence intervals
+confint(E1.est11, symmetricBias())
+confint(E1.est12, symmetricBias())
+confint(E1.est13, symmetricBias())
+confint(E1.est21, symmetricBias())
+confint(E1.est22, symmetricBias())
+confint(E1.est23, symmetricBias())
+
 
 ## 4. one-step estimation: radius interval
 E1.IC11 <- radiusMinimaxIC(L2Fam=ExpScaleFamily(scale=estimate(E1.est01)),
@@ -135,3 +144,11 @@ estimate(E1.est33)
 estimate(E1.est41)
 estimate(E1.est42)
 estimate(E1.est43)
+
+## confidence intervals
+confint(E1.est31, symmetricBias())
+confint(E1.est32, symmetricBias())
+confint(E1.est33, symmetricBias())
+confint(E1.est41, symmetricBias())
+confint(E1.est42, symmetricBias())
+confint(E1.est43, symmetricBias())
