@@ -2,6 +2,7 @@
 ## Example: Gamma Family
 ###############################################################################
 require(ROptEst)
+options("newDevice"=TRUE)
 
 ## generates Gamma Family with 
 ## scale = 2 and shape = 0.5
@@ -28,7 +29,7 @@ IC1
 checkIC(IC1)
 Risks(IC1)
 plot(IC1)
-devNew()
+#devNew()
 infoPlot(IC1)
 
 ## lower case solutions
@@ -65,14 +66,36 @@ ind <- rbinom(100, size=1, prob=0.05)
 x <- (1-ind)*rgamma(100, scale = 1, shape = 2) + ind*rgamma(100, scale = 3, shape = 5)
 
 ## 2. Kolmogorov(-Smirnov) minimum distance estimator
-(est0 <- MDEstimator(x=x, GammaFamily()))
+(est01 <- MDEstimator(x=x, GammaFamily()))
+
+## 3. Cramer von Mises minimum distance estimator
+(est02 <- MDEstimator(x = x, GammaFamily(), distance = CvMDist))
 
 ## non-robust ML estimator
 MLEstimator(x=x, GammaFamily())
 
-## 3. one-step estimation: radius known
-RobG3 <- InfRobModel(center=GammaFamily(scale = estimate(est0)["scale"], 
-                     shape = estimate(est0)["shape"]), 
+## 4. one-step estimation: radius known
+RobG3 <- InfRobModel(center=GammaFamily(scale = estimate(est02)["scale"], 
+                     shape = estimate(est02)["shape"]), 
                 neighbor=ContNeighborhood(radius=0.5))
 IC9 <- optIC(model=RobG3, risk=asMSE())
-(est1 <- oneStepEstimator(x, IC=IC9, start=estimate(est0)))
+(est1 <- oneStepEstimator(x, IC=IC9, start=est02))
+
+## 5. k-step estimation: radius known
+(est2 <- kStepEstimator(x, IC=IC9, start=est02, steps = 3))
+
+## It's simpler to use function roptest!
+(est3 <- roptest(x, eps = 0.5/sqrt(length(x)), L2Fam = GammaFamily()))
+(est4 <- roptest(x, eps = 0.5/sqrt(length(x)), L2Fam = GammaFamily(), steps = 3))
+
+## comparison
+estimate(est1)
+estimate(est3)
+estimate(est2)
+estimate(est4)
+
+## confidence intervals
+confint(est1, symmetricBias())
+confint(est3, symmetricBias())
+confint(est2, symmetricBias())
+confint(est4, symmetricBias())
